# Based on Rocky-8-KDE.ks from https://git.resf.org/sig_core/kickstarts/src/branch/r8
#
# To boot, you should be able to boot off of a 'boot' ISO,
#    or any other installable Rocky ISO.
# After DVD boot, modify kernel line to add pointer to ks hosted via http, e.g.:
#   inst.noverifyssl inst.ks=http://1.2.3.4/rocky9kde-test.ks
#
%pre
# This can be changed to specify installing from a different repo/version ref
# The pre script is used to write the details of the repo data, 
#    which is included in main kickstart below

INST_VERS=pub/rocky/9.3
MAJOR_VERS=9
# The URL and repo options are written to a ksi file for later inclusion in main kickstart
# This is done in order to more easily utilize the variables above
echo "url --url https://dl.rockylinux.org/$INST_VERS/BaseOS/\$basearch/os/" > /tmp/installVersInfo.ksi
echo "repo --name='BaseOS' --baseurl=http://dl.rockylinux.org/$INST_VERS/BaseOS/\$basearch/os/ --cost=200" >> /tmp/installVersInfo.ksi
echo "repo --name='AppStream' --baseurl=http://dl.rockylinux.org/$INST_VERS/AppStream/\$basearch/os/ --cost=200" >> /tmp/installVersInfo.ksi
echo "repo --name='CRB' --baseurl=http://dl.rockylinux.org/$INST_VERS/CRB/\$basearch/os/ --cost=200" >> /tmp/installVersInfo.ksi
echo "repo --name='extras' --baseurl=http://dl.rockylinux.org/$INST_VERS/extras/\$basearch/os --cost=200" >> /tmp/installVersInfo.ksi
echo "repo --name='epel' --baseurl=https://dl.fedoraproject.org/pub/epel/$MAJOR_VERS/Everything/\$basearch/ --cost=200" >> /tmp/installVersInfo.ksi
echo "repo --name='epel-modular' --baseurl=https://dl.fedoraproject.org/pub/epel/$MAJOR_VERS/Modular/\$basearch/ --cost=200" >> /tmp/installVersInfo.ksi
%end

#version=DEVEL
# X Window System configuration information
xconfig  --startxonboot
# Keyboard layouts
keyboard 'us'
# Root password
rootpw --iscrypted --lock locked
# Establish a test user that can login initially with defined password here:
user --name=rocky --groups=wheel,systemd-journal --password=rockylinux
# System language
lang en_US.UTF-8
# Shutdown after installation
shutdown
# Network information
network  --bootproto=dhcp --device=link --activate
# Firewall configuration
firewall --enabled --service=mdns
# Use network installation
# Now include the URL/repo info from the %pre script
%include /tmp/installVersInfo.ksi

# System timezone
timezone --utc Etc/UTC
# SELinux configuration
selinux --enforcing
# System services
services --disabled="sshd" --enabled="NetworkManager,ModemManager"
# System bootloader configuration
bootloader --location=mbr
# Clear the Master Boot Record
zerombr
# Partition clearing information
clearpart --all
# Disk partitioning information
# Bare-bones partitioning for this test
part /boot/efi --size=300 --ondisk=/dev/sda --fstype=efi --asprimary
part / --grow  --ondisk=/dev/sda


%packages
# Package list from Rocky-8-KDE
@^kde-desktop-environment
@anaconda-tools
@base-x
@core
@dial-up
@firefox
@fonts
@guest-desktop-agents
@hardware-support
@kde-apps
@kde-media
@multimedia
@standard
aajohan-comfortaa-fonts
anaconda
anaconda-install-env-deps
chkconfig
dracut-live
epel-release
fuse
glibc-all-langpacks
initscripts
kernel
kernel-modules
kernel-modules-extra
libreoffice-calc
libreoffice-emailmerge
libreoffice-graphicfilter
libreoffice-impress
libreoffice-writer
mariadb-connector-c
mariadb-embedded
mariadb-server
memtest86+
sddm
sddm-themes
sddm-breeze
sddm-kcm
syslinux
gjs
-@admin-tools
-@input-methods
-desktop-backgrounds-basic
-digikam
-gnome-disk-utility
-hplip
-iok
-isdn4k-utils
-k3b
-kdeaccessibility*
-kipi-plugins
-krusader
-ktorrent
-mpage
-scim*
-system-config-printer
-system-config-services
-system-config-users
-xsane
-xsane-gimp

%end
